@@ -1,7 +1,7 @@
 /*
  * gnote
  *
- * Copyright (C) 2012-2013,2017-2021 Aurimas Cernius
+ * Copyright (C) 2012-2013,2017-2022 Aurimas Cernius
  *
  * This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -19,11 +19,11 @@
 
 
 #include <algorithm>
+#include <condition_variable>
 #include <stdexcept>
 
 #include <glibmm/i18n.h>
 #include <glibmm/miscutils.h>
-#include <glibmm/thread.h>
 
 #include "debug.hpp"
 #include "filesystemsyncserver.hpp"
@@ -54,14 +54,14 @@ int str_to_int(const Glib::ustring & s)
 namespace gnote {
 namespace sync {
 
-SyncServer *FileSystemSyncServer::create(const Glib::RefPtr<Gio::File> & path, Preferences & prefs)
+SyncServer *FileSystemSyncServer::create(Glib::RefPtr<Gio::File> && path, Preferences & prefs)
 {
-  return new FileSystemSyncServer(path, prefs.sync_client_id());
+  return new FileSystemSyncServer(std::move(path), prefs.sync_client_id());
 }
 
 
-FileSystemSyncServer::FileSystemSyncServer(const Glib::RefPtr<Gio::File> & localSyncPath, const Glib::ustring & client_id)
-  : m_server_path(localSyncPath)
+FileSystemSyncServer::FileSystemSyncServer(Glib::RefPtr<Gio::File> && localSyncPath, const Glib::ustring & client_id)
+  : m_server_path(std::move(localSyncPath))
   , m_cache_path(Glib::build_filename(Glib::get_tmp_dir(), Glib::get_user_name(), "gnote"))
   , m_sync_lock(client_id)
 {
@@ -99,8 +99,8 @@ void FileSystemSyncServer::upload_notes(const std::vector<Note::Ptr> & notes)
   mkdir_p(m_new_revision_path);
   DBG_OUT("UploadNotes: notes.Count = %d", int(notes.size()));
   m_updated_notes.reserve(notes.size());
-  Glib::Mutex notes_lock;
-  Glib::Cond all_uploaded;
+  std::mutex notes_lock;
+  std::condition_variable all_uploaded;
   auto cancel_op = Gio::Cancellable::create();
   unsigned failures = 0;
   unsigned total = notes.size();
@@ -113,12 +113,11 @@ void FileSystemSyncServer::upload_notes(const std::vector<Note::Ptr> & notes)
       try {
         if(local_note->copy_finish(result)) {
           auto path = sharp::file_basename(file_path);
-          notes_lock.lock();
+          std::unique_lock<std::mutex> lock(notes_lock);
           m_updated_notes.emplace_back(std::move(path));
           if(--total == 0) {
-            all_uploaded.signal();
+            all_uploaded.notify_one();
           }
-          notes_lock.unlock();
           return;
         }
       }
@@ -126,22 +125,20 @@ void FileSystemSyncServer::upload_notes(const std::vector<Note::Ptr> & notes)
         ERR_OUT(_("Failed to upload note: %s"), e.what().c_str());
       }
 
-      notes_lock.lock();
+      std::unique_lock<std::mutex> lock(notes_lock);
       ++failures;
       --total;
-      all_uploaded.signal();
-      notes_lock.unlock();
+      all_uploaded.notify_one();
     }, cancel_op);
   }
 
-  notes_lock.lock();
+  std::unique_lock<std::mutex> lock(notes_lock);
   while(total > 0) {
-    all_uploaded.wait(notes_lock);
+    all_uploaded.wait(lock);
     if(failures > 0) {
       cancel_op->cancel();
     }
   }
-  notes_lock.unlock();
   if(failures > 0) {
     throw GnoteSyncException(Glib::ustring::compose(ngettext("Failed to upload %1 note", "Failed to upload %1 notes", failures), failures));
   }
@@ -181,8 +178,8 @@ bool FileSystemSyncServer::updates_available_since(int revision)
 
 std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since(int revision)
 {
-  Glib::Mutex note_updates_lock;
-  Glib::Cond note_updates_done;
+  std::mutex note_updates_lock;
+  std::condition_variable note_updates_done;
   std::map<Glib::ustring, NoteUpdate> noteUpdates;
   unsigned failures = 0;
 
@@ -228,12 +225,11 @@ std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since
                   Glib::ustring noteTitle;
                   Glib::ustring noteXml = sharp::file_read_all_text(noteTempPath);
                   NoteUpdate update(noteXml, noteTitle, note_id, rev);
-                  note_updates_lock.lock();
+                  std::unique_lock<std::mutex> lock(note_updates_lock);
                   noteUpdates.insert(std::make_pair(note_id, update));
                   if(noteUpdates.size() + failures >= total) {
-                    note_updates_done.signal();
+                    note_updates_done.notify_one();
                   }
-                  note_updates_lock.unlock();
                   return; // all done, error handling below
                 }
               }
@@ -244,22 +240,20 @@ std::map<Glib::ustring, NoteUpdate> FileSystemSyncServer::get_note_updates_since
                 ERR_OUT(_("Exception when finishing note copy"));
               }
 
-              note_updates_lock.lock();
+              std::unique_lock<std::mutex> lock(note_updates_lock);
               ++failures;
-              note_updates_done.signal();
-              note_updates_lock.unlock();
+              note_updates_done.notify_one();
             }, cancel_op);
         }
       }
 
-      note_updates_lock.lock();
+      std::unique_lock<std::mutex> lock(note_updates_lock);
       while(noteUpdates.size() + failures < noteNodes.size()) {
         if(failures > 0 && !cancel_op->is_cancelled()) {
           cancel_op->cancel();
         }
-        note_updates_done.wait(note_updates_lock);
+        note_updates_done.wait(lock);
       }
-      note_updates_lock.unlock();
     }
 
     xmlFreeDoc(xml_doc);
@@ -373,7 +367,8 @@ bool FileSystemSyncServer::commit_sync_transaction()
         manifest_file->remove();
       }
       auto stream = manifest_file->create_file();
-      stream->write(xml_content);
+      gsize written;
+      stream->write_all(xml_content, written);
       stream->close();
     }
     catch(...) {
@@ -633,7 +628,8 @@ void FileSystemSyncServer::update_lock_file(const SyncLockInfo & syncLockInfo)
 
     xml.close();
     auto stream = m_lock_path->replace();
-    stream->write(xml.to_string());
+    gsize written;
+    stream->write_all(xml.to_string(), written);
     stream->close();
   }
   catch(Glib::Error & e) {
